==> elixir-react-stateful-1.3.7.tgz: package/src/redux/index.js <==
import { applyMiddleware, createStore, compose, combineReducers } from "redux";
import logger from "redux-logger";
import createSagaMiddleware from "redux-saga";
import thunk from "redux-thunk";
// import rootReducer from "./reducers";
import rootSaga from "./sagas";
import general from "./reducers/general";
import viewStatus from "./reducers/viewStatus";
import tabs from "./reducers/tabs";
import { getCustomReducers } from "../initializer";

//import { getNotificationMethod } from "../initializer";
//import { showNotification } from "../config/notifications";

const bindMiddleware = (middleware) => applyMiddleware(...middleware);



const rootReducer = { general, viewStatus, tabs }


function createReducer(customReducers) {
  return combineReducers({
    ...rootReducer,
    ...customReducers
  })
}



function configureStore(initialState = {}) {
 //const showNotification = getNotificationMethod();
  const sagaMiddleware = createSagaMiddleware({
    onError: (error) => {
      //showNotification({ message: error.name, description: error.message, type: "error" });
    },
  });
  const middlewares = [thunk, sagaMiddleware];
  if (process.env.NODE_ENV === "development") {
    middlewares.push(logger);
  }
  const store = createStore(
    createReducer(getCustomReducers()),
    initialState,
    compose(bindMiddleware(middlewares),
      a => a,
    ),
  );
  store.injectReducer = (key, customReducer) => {
    if (!("customReducers" in store)) {
      store.customReducers = {}
    }
    store.customReducers[key] = customReducer
    store.replaceReducer(createReducer(store.customReducers))
  }

  store.sagaTask = sagaMiddleware.run(rootSaga);
  return store;
}

const store = configureStore();
export {store, configureStore};

==> elixir-react-stateful-1.3.9.tgz: package/src/redux/index.js <==
import { applyMiddleware, createStore, compose, combineReducers } from "redux";
import logger from "redux-logger";
import createSagaMiddleware from "redux-saga";
import thunk from "redux-thunk";
// import rootReducer from "./reducers";
import rootSaga from "./sagas";
import general from "./reducers/general";
import viewStatus from "./reducers/viewStatus";
import tabs from "./reducers/tabs";
//import { getCustomReducers } from "../initializer";

//import { getNotificationMethod } from "../initializer";
//import { showNotification } from "../config/notifications";

const bindMiddleware = (middleware) => applyMiddleware(...middleware);



const rootReducer = { general, viewStatus, tabs }


function createReducer(customReducers) {
  return combineReducers({
    ...rootReducer,
    ...customReducers
  })
}



function configureStore(initialState = {}) {
 //const showNotification = getNotificationMethod();
  const sagaMiddleware = createSagaMiddleware({
    onError: (error) => {
      //showNotification({ message: error.name, description: error.message, type: "error" });
    },
  });
  const middlewares = [thunk, sagaMiddleware];
  if (process.env.NODE_ENV === "development") {
    middlewares.push(logger);
  }
  const store = createStore(
    createReducer(),
    initialState,
    compose(bindMiddleware(middlewares),
      a => a,
    ),
  );
  store.injectReducer = (key, customReducer) => {
    if (!("customReducers" in store)) {
      store.customReducers = {}
    }
    store.customReducers[key] = customReducer
    store.replaceReducer(createReducer(store.customReducers))
  }

  store.sagaTask = sagaMiddleware.run(rootSaga);
  return store;
}

const store = configureStore();
export {store, configureStore};
